#! /usr/bin/env python
# coding: utf-8
"""
    Usage: cat descrip | ./make_table.py > index.html

    Examines the descrip file and builds a table, with five columns of
    the images, complete with text and links to the medium, large, full 
    size versions of the images.

    descrip looks like:

    100_2455   h   Driving down Miller Hill
    100_2549   v   Storage shed next to the red cabin

    Sizes:

        _thumb 150 x  200
        _med   600 x  800
        _lg    900 x 1200
        .jpg  1524 x 2032

    This script Copyright © 2007, Christopher Swingley, 
    <cswingle@gmail.com> and licensed under the terms of the GNU
    General Public License v3.0.  Use at your own risk.

"""

import sys
columns = 4
current_column = 1
print """<html><head>
<meta http-equiv="Content-Type" content="text/xhtml+xml; charset=UTF-8" />
<link rev="made" href="mailto:cswingle@gmail.com" />
<link rel="stylesheet" type="text/css" href="plain.css" title="Swingley Stylesheet" />
<title>Home Inspection, July 18, 2007</title>
</head><body>
<h3>Home Inspection, July 18, 2007</h3>
<div style="margin-left: 5%; margin-right: 5%;">

<p>We took a bunch of pictures of our potential new house during our home
inspection.  Click on the med, lg, or full links below each image to view the
images at different resolutions.</p>

<p>If you want to download all the images at once, click on the links below
(zipped file archives).</p>

<ul><li><a href="med_images.zip">Medium size, 600x800 images</a> (13 MB download)</li>
<li><a href="lg_images.zip">Large size, 900x1200 images</a> (25 MB download)</li>
<li><a href="full_images.zip">Full size, 1524x2032 images</a> (67 MB download)</li></ul>
</div>
<table cellspacing="5" cellpadding="5" border="0">
<tr width="100%">
"""
for line in sys.stdin.xreadlines():
    line = line.strip()
    fields = line.split()
    image_base, orientation = fields[:2]
    descrip = ' '.join(fields[2:])
    if not current_column % (columns + 1):
        print "</tr><tr>"
        current_column = 1
    if orientation == 'v':
        size = 'height="%s" width="%s"' % (200, 150)
    else:
        size = 'height="%s" width="%s"' % (150, 200)
    print '<td style="text-align:center;"><a href="%s_lg.html"><img src="%s_thumb.jpg" style="border: 0;" %s /></a><br />%s<br /><a href="%s_med.html">med</a>&nbsp;<a href="%s_lg.html">lg</a>&nbsp;<a href="%s.html">full</a>&nbsp;</td>' % (image_base, image_base, size, descrip, image_base, image_base, image_base)
    current_column += 1
print "</tr>"
print "</table>"
print """<div style="margin-left: 5%; margin-right: 5%;">

<hr />

<p>This page and all the pages that display images at various sizes was built
using a pair of Python scripts I wrote.  I started with a directory of full
size images and used the ImageMagick <tt>convert</tt> command to build a series
of images in different sizes.  Something like:</p>

<pre>
$ mkdir processed
$ for i in for i in `ls *.jpg`; do convert -resize 200x200 $i processed/${i%%.*}_thumb.jpg; done
$ for i in for i in `ls *.jpg`; do convert -resize 800x800 $i processed/${i%%.*}_med.jpg; done
$ for i in for i in `ls *.jpg`; do convert -resize 1200x1200 $i processed/${i%%.*}_lg.jpg; done
</pre>

<p>Then I copied all the full size images into the processed directory:</p>

<pre>
$ cp *.jpg processed/.
</pre>

<p>I wrote a description file (<tt><a href="descrip">descrip</a></tt>) that contains a list of all
the image numbers (the part of the image filename before the <tt>_thumb</tt> or
<tt>_med</tt>, etc.), whether the images were vertical or horizontal, and a
description of the photo.  Here are a few lines of <tt>descrip</tt>:</p>

<pre>
100_2455   h   Driving down Miller Hill
100_2549   v   Storage shed next to the red cabin
100_2550   h   Storage shed next to the red cabin
100_2545   v   Gate into southern dog yard area, covered dog shed in the back
</pre>

<p>They’re in the order I want them displayed on the pages.</p>

<p>Then I run <a href="make_table.py">make_table.py</a> to generate the main
page (the one you're on now):</p>

<pre>
$ cat descrip | ./make_table.py > index.html
</pre>

<p>Finally, run <a href="make_individual_html.py">make_individual_html.py</a>:</p>

<pre>
$ cat descrip | make_individual_html.py
</pre>

<p>to make all the individual pages for all the images in each size.  There's
also a CSS file named <a href="plain.css"><tt>plain.css</tt></a> that I used to
tweak the formatting a bit.</p>

<p>The great thing about this approach (writing short programs to build the
HTML) is that it's really easy to change it later on do look differently, or
organize the files in another way.  Another approach would be to use PHP to
parse the <tt>descrip</tt> file and build the pages dynamically.  Or use a
graphical tool to do it (Adobe PhotoShop, Bridge, Dreamweaver, etc.), but as
you can guess, I like the hands-on approach.</p>

</div>

</body></html>"""
